@@ -18,13 +18,15 @@
 
 import sys
 import time
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 
 from gvmtools.helper import error_and_exit
 
 
 def check_args(args):
     len_args = len(args.script) - 1
-    if len_args is not 2:
+    if len_args != 2:
         message = """
         This script pulls hostnames from a text file and creates a target \
 for each.
@@ -44,12 +46,12 @@ ssh --hostname <gsm> scripts/create_targets_from_host_list.gmp \
 
 def load_host_list(host_file):
     try:
-        with open(host_file) as f:
+        with open(host_file, encoding='utf-8') as f:
             content = f.readlines()
         host_list = [x.strip() for x in content]
         host_list = list(filter(None, host_list))
     except IOError as e:
-        error_and_exit("Failed to read host_file: {} (exit)".format(str(e)))
+        error_and_exit(f"Failed to read host_file: {str(e)} (exit)")
 
     if len(host_list) == 0:
         error_and_exit("Host file is empty (exit)")
@@ -58,17 +60,17 @@ def load_host_list(host_file):
 
 
 def send_targets(gmp, host_name, host_file, host_list):
-    print('\nSending targets from {} to {}...'.format(host_file, host_name))
+    print(f'\nSending targets from {host_file} to {host_name}...')
 
     for host in host_list:
-        name = "Target for {}".format(host)
-        comment = "Created: {}".format(time.strftime("%Y/%m/%d-%H:%M:%S"))
+        name = f"Target for {host}"
+        comment = f"Created: {time.strftime('%Y/%m/%d-%H:%M:%S')}"
         hosts = [host]
 
         gmp.create_target(name=name, comment=comment, hosts=hosts)
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
     # pylint: disable=undefined-variable
 
     check_args(args)
