@@ -18,6 +18,8 @@
 
 import datetime
 import sys
+from argparse import Namespace
+from gvm.protocols.gmp import Gmp
 
 
 def check_args(args):
@@ -26,8 +28,12 @@ def check_args(args):
         This script starts a new scan on the given host.
         It needs one parameters after the script name.
 
-        1. <host_ip>     -- IP Address of the host system
-        2. <port_list_id>     -- Port List UUID for scanning the host system. Preconfigured UUID might be under /var/lib/gvm/data-objects/gvmd/20.08/port_lists/. ex. iana-tcp-udp is "4a4717fe-57d2-11e1-9a26-406186ea4fc5".
+        1. <host_ip>        IP Address of the host system
+        2. <port_list_id>   Port List UUID for scanning the host system. 
+                            Preconfigured UUID might be under 
+                            /var/lib/gvm/data-objects/gvmd/20.08/port_lists/. 
+                            ex. iana-tcp-udp is 
+                            "4a4717fe-57d2-11e1-9a26-406186ea4fc5".
         
                 Example:
             $ gvm-script --gmp-username name --gmp-password pass \
@@ -40,7 +46,7 @@ ssh --hostname <gsm> scripts/scan-new-system.gmp.py <host_ip> <port_list_id>
 
 def create_target(gmp, ipaddress, port_list_id):
     # create a unique name by adding the current datetime
-    name = "Suspect Host {} {}".format(ipaddress, str(datetime.datetime.now()))
+    name = f"Suspect Host {ipaddress} {str(datetime.datetime.now())}"
 
     response = gmp.create_target(
         name=name, hosts=[ipaddress], port_list_id=port_list_id
@@ -49,7 +55,7 @@ def create_target(gmp, ipaddress, port_list_id):
 
 
 def create_task(gmp, ipaddress, target_id, scan_config_id, scanner_id):
-    name = "Scan Suspect Host {}".format(ipaddress)
+    name = f"Scan Suspect Host {ipaddress}"
     response = gmp.create_task(
         name=name,
         config_id=scan_config_id,
@@ -66,7 +72,7 @@ def start_task(gmp, task_id):
     return response[0].text
 
 
-def main(gmp, args):
+def main(gmp: Gmp, args: Namespace) -> None:
 
     check_args(args)
 
@@ -88,9 +94,8 @@ def main(gmp, args):
     report_id = start_task(gmp, task_id)
 
     print(
-        "Started scan of host {}. Corresponding report ID is {}".format(
-            ipaddress, report_id
-        )
+        f"Started scan of host {ipaddress}. "
+        f"Corresponding report ID is {report_id}"
     )
 
 
